Enum TypedTransaction

pub enum TypedTransaction {
    Legacy(TransactionRequest),
    Eip2930(Eip2930TransactionRequest),
    Eip1559(Eip1559TransactionRequest),
    DepositTransaction(DepositTransaction),
}
The TypedTransaction enum represents all Ethereum transaction types.

Its variants correspond to specific allowed transactions:

  1. Legacy (pre-EIP2718) TransactionRequest
  2. EIP2930 (state access lists) Eip2930TransactionRequest
  3. EIP1559 Eip1559TransactionRequest

To support Kovan and other non-London-compatbile networks, please enable the legacy crate feature. This will disable the type flag in the serialized transaction, and cause contract calls and other common actions to default to using the legacy transaction type.

Variants

Implementations

Source

impl TypedTransaction

pub fn from(&self) -> Option<&H160>

pub fn set_from(&mut self, from: H160) -> &mut TypedTransaction

pub fn to(&self) -> Option<&NameOrAddress>

pub fn to_addr(&self) -> Option<&H160>

pub fn set_to<T>(&mut self, to: T) -> &mut TypedTransaction
where T: Into<NameOrAddress>,

pub fn nonce(&self) -> Option<&U256>

pub fn set_nonce<T>(&mut self, nonce: T) -> &mut TypedTransaction
where T: Into<U256>,

pub fn value(&self) -> Option<&U256>

pub fn set_value<T>(&mut self, value: T) -> &mut TypedTransaction
where T: Into<U256>,

pub fn gas(&self) -> Option<&U256>

pub fn gas_mut(&mut self) -> &mut Option<U256>

pub fn set_gas<T>(&mut self, gas: T) -> &mut TypedTransaction
where T: Into<U256>,

pub fn gas_price(&self) -> Option<U256>

pub fn set_gas_price<T>(&mut self, gas_price: T) -> &mut TypedTransaction
where T: Into<U256>,

pub fn chain_id(&self) -> Option<U64>

pub fn set_chain_id<T>(&mut self, chain_id: T) -> &mut TypedTransaction
where T: Into<U64>,

pub fn data(&self) -> Option<&Bytes>

pub fn access_list(&self) -> Option<&AccessList>

pub fn set_access_list( &mut self, access_list: AccessList, ) -> &mut TypedTransaction

pub fn set_data(&mut self, data: Bytes) -> &mut TypedTransaction

pub fn rlp_signed(&self, signature: &Signature) -> Bytes

pub fn rlp(&self) -> Bytes

pub fn sighash(&self) -> H256

Hashes the transaction’s data. Does not double-RLP encode

pub fn max_cost(&self) -> Option<U256>

Max cost of the transaction

pub fn hash(&self, signature: &Signature) -> H256

Hashes the transaction’s data with the included signature.

pub fn decode_signed( rlp: &Rlp<'_>, ) -> Result<(TypedTransaction, Signature), TypedTransactionError>

Decodes a signed TypedTransaction from a rlp encoded byte stream

Source

impl TypedTransaction